import { useState, useEffect } from 'react';
import { Link, useLocation, useNavigate } from 'react-router-dom';
import { Cake, LogOut, Menu, ShoppingBag, User, X } from 'lucide-react';

import { useCartStore } from '@/lib/store';
import { useAuthStore } from '@/lib/authStore';

import { Button } from '@/components/ui/button';
import {
  Sheet,
  SheetContent,
  SheetDescription,
  SheetTitle,
  SheetTrigger,
} from '@/components/ui/sheet';
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from '@/components/ui/dropdown-menu';

export default function Header() {
  const pathname = useLocation().pathname;
  const navigate = useNavigate();

  const { cart, initializeCart } = useCartStore();
  const { user, isAuthenticated, logout } = useAuthStore();

  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  useEffect(() => {
    initializeCart();
  }, [initializeCart]);

  const totalItems = cart.reduce((total, item) => total + item.quantity, 0);

  const navItems = [
    { name: 'Home', path: '/' },
    { name: 'Menu', path: '/menu' },
    { name: 'About', path: '/about' },
    { name: 'Contact', path: '/contact' },
  ];

  const handleLogout = () => {
    logout();
    navigate('/');
  };

  return (
    <header className='sticky top-0 z-50 w-full bg-white/75 shadow-sm backdrop-blur-sm'>
      <div className='container mx-auto px-4 md:px-6'>
        <div className='flex h-20 items-center justify-between'>
          <Link to='/' className='inline-flex items-center space-x-2'>
            <Cake className='h-8 w-8 text-pink-500' />
            <span className='font-bold mt-2.5 text-xl font-script text-gray-800'>
              Golden Crust <span className='hidden md:inline'>Bakery</span>
            </span>
          </Link>

          <nav className='hidden md:flex items-center space-x-8'>
            {navItems.map((item) => (
              <Link
                key={item.path}
                to={item.path}
                className={`font-medium transition-colors hover:text-pink-500 ${
                  pathname === item.path ? 'text-pink-500' : 'text-gray-600'
                }`}
              >
                {item.name}
              </Link>
            ))}

            {isAuthenticated && (
              <Link
                to='/orders'
                className={`font-medium transition-colors hover:text-pink-500 ${
                  pathname === '/orders' ? 'text-pink-500' : 'text-gray-600'
                }`}
              >
                My Orders
              </Link>
            )}
          </nav>

          <div className='flex items-center space-x-4'>
            {isAuthenticated ? (
              <>
                <Button
                  variant='ghost'
                  size='icon'
                  onClick={() => navigate('/cart')}
                  className='relative'
                  aria-label='Shopping cart'
                >
                  <ShoppingBag className='h-6 w-6 text-gray-700' />
                  {totalItems > 0 && (
                    <span className='absolute -top-1 -right-1 flex h-5 w-5 items-center justify-center rounded-full bg-pink-500 text-xs font-medium text-white'>
                      {totalItems}
                    </span>
                  )}
                </Button>

                <DropdownMenu>
                  <DropdownMenuTrigger asChild>
                    <Button
                      variant='ghost'
                      size='icon'
                      className='relative'
                      aria-label='User menu'
                    >
                      <User className='h-6 w-6 text-gray-700' />
                    </Button>
                  </DropdownMenuTrigger>
                  <DropdownMenuContent align='end' className='w-56'>
                    <DropdownMenuLabel>
                      <div className='flex flex-col'>
                        <span>My Account</span>
                        <span className='text-xs font-normal text-gray-500'>
                          {user?.email}
                        </span>
                      </div>
                    </DropdownMenuLabel>
                    <DropdownMenuSeparator />
                    <DropdownMenuItem onClick={() => navigate('/profile')}>
                      <User className='mr-2 h-4 w-4' /> Profile
                    </DropdownMenuItem>
                    <DropdownMenuItem onClick={() => navigate('/orders')}>
                      <ShoppingBag className='mr-2 h-4 w-4' /> My Orders
                    </DropdownMenuItem>
                    <DropdownMenuSeparator />
                    <DropdownMenuItem onClick={handleLogout}>
                      <LogOut className='mr-2 h-4 w-4' /> Logout
                    </DropdownMenuItem>
                  </DropdownMenuContent>
                </DropdownMenu>
              </>
            ) : (
              <Button
                onClick={() => navigate('/login')}
                className='bg-pink-500 hover:bg-pink-600 text-white rounded-full'
              >
                Sign In
              </Button>
            )}

            <Sheet open={isMobileMenuOpen} onOpenChange={setIsMobileMenuOpen}>
              <SheetTitle className='sr-only'>Menu</SheetTitle>
              <SheetDescription className='sr-only'>
                Menubar for mobile devices. Not visible on desktop.
              </SheetDescription>
              <SheetTrigger asChild>
                <Button
                  variant='ghost'
                  size='icon'
                  className='md:hidden'
                  aria-label='Menu'
                >
                  <Menu className='h-6 w-6 text-gray-700' />
                </Button>
              </SheetTrigger>
              <SheetContent side='right' className='w-[300px] sm:w-[400px]'>
                <div className='flex flex-col h-full'>
                  <div className='flex items-center justify-between mb-6'>
                    <div className='flex items-center space-x-2'>
                      <Cake className='h-6 w-6 text-pink-500' />
                      <span className='font-bold font-script mt-2 text-lg text-gray-900'>
                        Golden Crust
                      </span>
                    </div>
                  </div>
                  <nav className='flex flex-col space-y-4'>
                    {navItems.map((item) => (
                      <Link
                        key={item.path}
                        to={item.path}
                        className={`text-base font-medium transition-colors hover:text-pink-500 ${
                          pathname === item.path
                            ? 'text-pink-500'
                            : 'text-gray-600'
                        }`}
                        onClick={() => setIsMobileMenuOpen(false)}
                      >
                        {item.name}
                      </Link>
                    ))}
                    {isAuthenticated && (
                      <Link
                        to='/orders'
                        className={`text-base font-medium transition-colors hover:text-pink-500 ${
                          pathname === '/orders'
                            ? 'text-pink-500'
                            : 'text-gray-600'
                        }`}
                        onClick={() => setIsMobileMenuOpen(false)}
                      >
                        My Orders
                      </Link>
                    )}
                  </nav>
                  <div className='mt-auto pt-6'>
                    {isAuthenticated ? (
                      <>
                        <Button
                          onClick={() => {
                            navigate('/cart');
                            setIsMobileMenuOpen(false);
                          }}
                          className='w-full bg-pink-500 hover:bg-pink-600 text-white rounded-full mb-4'
                        >
                          <ShoppingBag className='mr-2 h-4 w-4' />
                          View Cart {totalItems > 0 && `(${totalItems})`}
                        </Button>
                        <Button
                          variant='outline'
                          onClick={handleLogout}
                          className='w-full border-red-300 text-red-600 hover:bg-red-50 rounded-full'
                        >
                          <LogOut className='mr-2 h-4 w-4' /> Logout
                        </Button>
                      </>
                    ) : (
                      <div className='space-y-4'>
                        <Button
                          onClick={() => {
                            navigate('/login');
                            setIsMobileMenuOpen(false);
                          }}
                          className='w-full bg-pink-500 hover:bg-pink-600 text-white rounded-full'
                        >
                          Sign In
                        </Button>
                        <Button
                          variant='outline'
                          onClick={() => {
                            navigate('/register');
                            setIsMobileMenuOpen(false);
                          }}
                          className='w-full border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full'
                        >
                          Create Account
                        </Button>
                      </div>
                    )}
                  </div>
                </div>
              </SheetContent>
            </Sheet>
          </div>
        </div>
      </div>
    </header>
  );
}
